@@ -54,6 +54,7 @@ package App::Greple::dig;
 __DATA__
 
 expand is_repository	( -name .git -o -name .svn -o -name RCS -o -name CVS )
+expand is_temporary	( -name .build -o -name _build )
 expand is_dots		  -name .*
 expand is_version	  -name *,v
 expand is_backup	( -name *~ -o -name *.swp )
@@ -74,7 +75,8 @@ expand is_others	( -name *.bundle -o -name *.dylib -o -name *.o -o \
 option --dig -Mfind \
 	$<move> \
 	( \
-		is_repository -prune -o \
+		( is_repository -o is_temporary ) \
+		-prune -o \
 		-type f \
 	) \
 	! is_dots \
